pub struct TagCreateBuilder { /* private fields */ }Expand description
Builder for constructing validated tag create payloads.
Implementations
Sourceimpl TagCreateBuilder
impl TagCreateBuilder
Sourcepub fn new(name: impl Into<String>, workspace: impl Into<String>) -> Self
pub fn new(name: impl Into<String>, workspace: impl Into<String>) -> Self
Start building a new tag payload with the required name and workspace.
Sourcepub fn build(self) -> Result<TagCreateRequest, TagValidationError>
pub fn build(self) -> Result<TagCreateRequest, TagValidationError>
Finalise the builder into a request payload performing validation.
Errors
Returns a validation error if mandatory fields are missing or invalid.