Asana API client abstractions. Asana API client module providing authenticated HTTP access, pagination, and rate-limit aware retry logic.
Re-exports
pub use attachments::delete_attachment;pub use attachments::download_attachment;pub use attachments::get_attachment;pub use attachments::list_attachments;pub use attachments::upload_attachment;pub use auth::AuthToken;pub use auth::StaticTokenProvider;pub use auth::TokenProvider;pub use client::ApiClient;pub use client::ApiClientBuilder;pub use client::ApiClientOptions;pub use custom_fields::get_custom_field;pub use custom_fields::list_custom_fields;pub use error::ApiError;pub use error::RateLimitInfo;pub use pagination::ListResponse;pub use pagination::PaginationInfo;pub use projects::add_members;pub use projects::create_project;pub use projects::delete_project;pub use projects::get_project;pub use projects::list_members;pub use projects::list_projects;pub use projects::list_statuses;pub use projects::remove_members;pub use projects::update_member;pub use projects::update_project;pub use sections::add_task_to_section;pub use sections::create_section;pub use sections::delete_section;pub use sections::get_section;pub use sections::get_section_tasks;pub use sections::list_sections;pub use sections::update_section;pub use stories::create_story;pub use stories::delete_story;pub use stories::get_story;pub use stories::list_stories;pub use stories::update_story;pub use tags::create_tag;pub use tags::delete_tag;pub use tags::get_tag;pub use tags::update_tag;pub use tasks::add_dependencies;pub use tasks::add_dependents;pub use tasks::add_followers;pub use tasks::add_project;pub use tasks::add_tag;pub use tasks::create_task;pub use tasks::delete_task;pub use tasks::get_task;pub use tasks::list_dependencies;pub use tasks::list_dependents;pub use tasks::list_subtasks;pub use tasks::list_tasks;pub use tasks::remove_dependencies;pub use tasks::remove_dependents;pub use tasks::remove_followers;pub use tasks::remove_project;pub use tasks::remove_tag;pub use tasks::search_tasks;pub use tasks::update_task;pub use users::get_current_user;pub use users::get_user;pub use users::list_users;pub use workspaces::get_workspace;pub use workspaces::list_workspaces;
Modules
- attachments
- High level attachment operations built on the core API client.
- auth
- Authentication helpers for the Asana API client.
- client
- Core asynchronous HTTP client for interacting with Asana’s REST API.
- custom_
fields - High level custom field operations built on the core API client.
- error
- Error types for the Asana API client.
- pagination
- Pagination helpers matching Asana’s REST API structure.
- projects
- High level project operations built on the core API client.
- sections
- High level section operations built on the core API client.
- stories
- High level story (comment) operations built on the core API client.
- tags
- High level tag operations built on the core API client.
- tasks
- High level task operations built on the core API client.
- users
- High level user operations built on the core API client.
- workspaces
- High level workspace operations built on the core API client.